==> haskell-math-functions-0.3.4.2-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 math-functions
version:              0.3.4.2
visibility:           public
id:                   math-functions-0.3.4.2-Cq39zqb9OGAIqQkhA05bae
key:                  math-functions-0.3.4.2-Cq39zqb9OGAIqQkhA05bae
license:              BSD-2-Clause
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Alexey Khudyakov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/math-functions
synopsis:             Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.

category:             Math, Numeric
abi:                  cfef1c4e37a982f52fd8b9193965eeba
exposed:              True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.SpecFunctions.Internal Numeric.Sum

hidden-modules:       Numeric.SpecFunctions.Compat
import-dirs:          /usr/lib/ghc-9.0.1/site-local/math-functions-0.3.4.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/math-functions-0.3.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/math-functions-0.3.4.2
hs-libraries:         HSmath-functions-0.3.4.2-Cq39zqb9OGAIqQkhA05bae
depends:
    base-4.15.0.0 data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC
    deepseq-1.4.5.0 primitive-0.7.1.0-4kINdDpEhvmA3u6QNQy1Pc
    vector-0.12.3.0-AUL3Ah3IbB92NFyYgYDz3e

haddock-interfaces:
    /usr/share/doc/haskell-math-functions/html/math-functions.haddock

haddock-html:         /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-math-functions-0.3.4.2-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 math-functions
version:              0.3.4.2
visibility:           public
id:                   math-functions-0.3.4.2-HsBxoubD4jfDhGFYRCI6Y3
key:                  math-functions-0.3.4.2-HsBxoubD4jfDhGFYRCI6Y3
license:              BSD-2-Clause
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Alexey Khudyakov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/math-functions
synopsis:             Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.

category:             Math, Numeric
abi:                  28a35bc82b6ba3632acde1e3ca0f11e2
exposed:              True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.SpecFunctions.Internal Numeric.Sum

hidden-modules:       Numeric.SpecFunctions.Compat
import-dirs:          /usr/lib/ghc-9.0.1/site-local/math-functions-0.3.4.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/math-functions-0.3.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/math-functions-0.3.4.2
hs-libraries:         HSmath-functions-0.3.4.2-HsBxoubD4jfDhGFYRCI6Y3
depends:
    base-4.15.0.0 data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC
    deepseq-1.4.5.0 primitive-0.7.2.0-H9HP2FbaY5C1JlRHDKja9P
    vector-0.12.3.0-CgoUHetGdHJ8g5PEq7W8KZ

haddock-interfaces:
    /usr/share/doc/haskell-math-functions/html/math-functions.haddock

haddock-html:         /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
